# AskGoogle
Automatically redirects to Google when an exception is thrown <br>
Inspired by [Gary50613/askoverflow.js](https://github.com/Gary50613/askoverflow.js)

## Installation
```shell
$ pip install askgoogle
```

## Usage
```python
import askgoogle

# code everything you want!

```